@@ -1,3 +1,65 @@
+#' Double factorial scheme plus one additional treatment
+#' in RBD
+#'
+#' \code{fat2.ad.rbd} Analyses experiments in balanced
+#' Randomized Blocks Designs in double factorial scheme
+#' with an additional treatment, considering a fixed model.
+#' @param factor1 Numeric or complex vector containing the
+#' factor 1 levels.
+#' @param factor2 Numeric or complex vector containing the
+#' factor 2 levels.
+#' @param block Numeric or complex vector containing the
+#' blocks.
+#' @param resp Numeric or complex vector containing the
+#' response variable.
+#' @param respAd Numeric or complex vector containing the
+#' additional treatment.
+#' @param quali Logic. If TRUE (default), the treatments
+#' are assumed qualitative, if FALSE, quantitatives.
+#' @param mcomp Allows choosing the multiple comparison
+#' test; the \emph{default} is the test of Tukey, however,
+#' the options are: the LSD test ('lsd'), the LSD test
+#' with Bonferroni protection ('lsdb'), the test of Duncan
+#' ('duncan'), the test of Student-Newman-Keuls ('snk'),
+#' the test of Scott-Knott ('sk'), the Calinski and
+#' Corsten test ('ccF') and bootstrap multiple comparison's
+#' test ('ccboot').
+#' @param fac.names Allows labeling the factors 1 and 2.
+#' @param sigT The signficance to be used for the multiple
+#' comparison test; the default is 5\%.
+#' @param sigF The signficance to be used for the F test
+#' of ANOVA; the default is 5\%.
+#' @details The arguments sigT and mcomp will be used only
+#' when the treatment are qualitative.
+#' @return The output contains the ANOVA of the referred
+#' RBD, the Shapiro-Wilk normality test for the residuals
+#' of the model, the fitted regression models (when the
+#' treatments are quantitative) and/or the multiple
+#' comparison tests (when the treatments are qualitative).
+#' @references HEALY, M. J. R. The analysis of a factorial
+#' experiment with additional treatments. Journal of
+#' Agricultural Science, Cambridge, v. 47, p. 205-206.
+#' 1956.
+#' @author Eric B Ferreira,
+#'  \email{eric.ferreira@@unifal-mg.edu.br}
+#' @author Denismar Alves Nogueira
+#' @author Portya Piscitelli Cavalcanti
+#' @note The \code{\link{graphics}} can be used to
+#' construct regression plots and \code{\link{plotres}}
+#' for residuals plots.
+#' @seealso \code{\link{fat2.crd}}, \code{\link{fat2.rbd}},
+#' \code{\link{fat3.crd}}, \code{\link{fat3.rbd}},
+#' \code{\link{fat2.ad.crd}}, \code{\link{fat2.ad.rbd}},
+#' \code{\link{fat3.ad.crd}} and \code{\link{fat3.ad.rbd}}.
+#' @examples
+#' data(ex7)
+#' attach(ex7)
+#' data(est21Ad)
+#' fat2.ad.rbd(periodo, nivel, bloco, est21, est21Ad,
+#' quali=c(TRUE, FALSE), mcomp = "tukey", fac.names =
+#' c("Period", "Level"), sigT = 0.05, sigF = 0.05)
+#' @export
+
 fat2.ad.rbd <-
 function(factor1, factor2, block, resp, respAd, quali=c(TRUE,TRUE), mcomp='tukey', fac.names=c('F1','F2'), sigT=0.05, sigF=0.05) {
 
@@ -5,7 +67,6 @@ cat('------------------------------------------------------------------------\nL
 cat('FACTOR 1: ',fac.names[1],'\n')
 cat('FACTOR 2: ',fac.names[2],'\n------------------------------------------------------------------------\n\n')
 
-
 fatores<-cbind(factor1,factor2)
 Fator1<-factor(factor1)
 Fator2<-factor(factor2)
@@ -19,7 +80,6 @@ n.trat2<-nv1*nv2
 
 #ANAVA do fatorial 2
 anavaF2<-summary(aov(resp~ Block + Fator1*Fator2))
-
 SQa<-anavaF2[[1]][2,2]
 SQb<-anavaF2[[1]][3,2]
 SQab<-anavaF2[[1]][4,2]
@@ -27,7 +87,7 @@ SQab<-anavaF2[[1]][4,2]
 #Anava de todos os tratamentos do experimento (fatorial 2 + adicional)
 col1<-numeric(0)
 for(i in 1:n.trat2) {
-col1<-c(col1, rep(i,J))     
+col1<-c(col1, rep(i,J))
                     }
 col1<-c(col1,rep('ad',J))
 col2<-c(block,rep(1:J))
@@ -37,20 +97,17 @@ TRAT2<-factor(tabF2ad[,1])
 BLOCK<-factor(tabF2ad[,2])
 anava<-aov(tabF2ad[,3]~ BLOCK + TRAT2)
 anavaTr<-summary(anava)
-
 SQB<-anavaTr[[1]][1,2]
 SQad<-anavaTr[[1]][2,2] - (SQa+SQb+SQab)
 SQE<-anavaTr[[1]][3,2]
 SQT<-anavaTr[[1]][1,2]+anavaTr[[1]][2,2]+anavaTr[[1]][3,2]
-
 glB=J-1
 gla=nv1-1
 glb=nv2-1
 glab=(nv1-1)*(nv2-1)
 glad=1
-glE=(nv1*nv2+1)*(J-1)-(J-1)   
+glE=(nv1*nv2+1)*(J-1)-(J-1)
 glT=(nv1*nv2+1)*J-1
-
 QMB=SQB/glB
 QMa=SQa/gla
 QMb=SQb/glb
@@ -58,13 +115,11 @@ QMab=SQab/glab
 QMad=SQad/glad
 QME=SQE/glE
 QMT=SQT/glT
-
 FcB=QMB/QME
 Fca=QMa/QME
 Fcb=QMb/QME
 Fcab=QMab/QME
 Fcad=QMad/QME
-
 pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE))
 
 #Montando a tabela da ANAVA
@@ -80,7 +135,7 @@ Analysis of Variance Table\n----------------------------------------------------
 print(anavaT)
 cat('------------------------------------------------------------------------\n')
 #CV
-cv<-round(sqrt(as.numeric(anavaT[6,3]))/mean(col3)*100, 2)
+cv<-round(sqrt(QME)/mean(col3)*100, 2)
 cat('CV =',cv,'%\n')
 
 
@@ -113,7 +168,7 @@ print(C2)
 cat('------------------------------------------------------------------------\n')
 
 #Para interacao nao significativa, fazer...
-if(1-pf(Fcab,glab,glE)>sigF) {                            
+if(1-pf(Fcab,glab,glE)>sigF) {
 cat('\nNo significant interaction: analyzing the simple effect
 ------------------------------------------------------------------------\n')
 fatores<-data.frame('fator 1'=factor1,'fator 2' = factor2)
@@ -124,7 +179,7 @@ for(i in 1:2){
 if(quali[i]==TRUE && pv.fs[i]<=sigF) {
     cat(fac.names[i])
       if(mcomp=='tukey'){
-    tukey(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)                                 
+    tukey(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)
                     }
   if(mcomp=='duncan'){
     duncan(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)
@@ -144,8 +199,8 @@ if(quali[i]==TRUE && pv.fs[i]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)
                     }
-  if(mcomp=="ccf"){
-    ccf(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)
+  if(mcomp=="ccF"){
+    ccF(resp,fatores[,i],anavaT[6,1],anavaT[6,2],sigT)
                   }
                    }
 if(quali[i]==TRUE && pv.fs[i]>sigF) {
@@ -159,7 +214,7 @@ cat('------------------------------------------------------------------------')
 }
 
 #Para os fatores QUANTITATIVOS, regressao
-if(quali[i]==FALSE && pv.fs[i]<=sigF){                              
+if(quali[i]==FALSE && pv.fs[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], anavaT[6,1],anavaT[6,2], anavaT[i+1,1], anavaT[i+1,2])
 }
@@ -180,7 +235,7 @@ cat('\n')
 }
 
 #Se a interacao for significativa, desdobrar a interacao
-if(1-pf(Fcab,glab,glE)<=sigF){                                          
+if(1-pf(Fcab,glab,glE)<=sigF){
 cat("\n\n\nSignificant interaction: analyzing the interaction
 ------------------------------------------------------------------------\n")
 
@@ -227,17 +282,17 @@ cat('------------------------------------------------------------------------\n\
 
 ii<-0
 for(i in 1:nv2) {
-ii<-ii+1  
-  if(1-pf(Fcf1,glf1,glE)[ii]<=sigF){                                       
+ii<-ii+1
+  if(1-pf(Fcf1,glf1,glE)[ii]<=sigF){
     if(quali[1]==TRUE){
                       cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
                         if(mcomp=='tukey'){
                           tukey(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
-                                          }                                  
+                                          }
                         if(mcomp=='duncan'){
-                          duncan(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)            
-                                           }                   
+                          duncan(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
+                                           }
                         if(mcomp=='lsd'){
                           lsd(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
                                         }
@@ -253,14 +308,14 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
                                             }
-                        if(mcomp=="ccf"){
-                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
+                        if(mcomp=="ccF"){
+                          ccF(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],anavaT[6,1],anavaT[6,2],sigT)
                                         }
                       }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
-    reg.poly(resp[Fator2==lf2[i]], factor1[Fator2==lf2[i]], anavaT[6,1], anavaT[6,2], anavad1[i+2,1], anavad1[i+2,2])          
+    reg.poly(resp[Fator2==lf2[i]], factor1[Fator2==lf2[i]], anavaT[6,1], anavaT[6,2], anavad1[i+2,1], anavad1[i+2,2])
         }
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'\n')
@@ -270,14 +325,14 @@ ii<-ii+1
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
         cat('------------------------------------------------------------------------\n')
-        }                          
+        }
                  }
 cat('\n\n')
 
 #Desdobramento de FATOR 2 dentro do niveis de FATOR 1
 cat("\nAnalyzing ", fac.names[2], ' inside of each level of ', fac.names[1], '
 ------------------------------------------------------------------------\n')
-    
+
 des2<-aov(resp~ Block + Fator1/Fator2)
 
 l2<-vector('list',nv1)
@@ -317,7 +372,7 @@ cat('------------------------------------------------------------------------\n\
 ii<-0
 for(i in 1:nv1) {
   ii<-ii+1
-  if(1-pf(Fcf2,glf2,glE)[ii]<=sigF){                               
+  if(1-pf(Fcf2,glf2,glE)[ii]<=sigF){
     if(quali[2]==TRUE){
                       cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'
 ------------------------------------------------------------------------')
@@ -325,8 +380,8 @@ for(i in 1:nv1) {
                           tukey(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
                                           }
                         if(mcomp=='duncan'){
-                          duncan(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)            
-                                           }                   
+                          duncan(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
+                                           }
                         if(mcomp=='lsd'){
                           lsd(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
                                         }
@@ -342,8 +397,8 @@ for(i in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
+                        if(mcomp=="ccF"){
+                          ccF(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],anavaT[6,1],anavaT[6,2],sigT)
                                         }
                       }
     else{  #regressao
@@ -359,7 +414,7 @@ for(i in 1:nv1) {
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
         cat('------------------------------------------------------------------------\n')
-        }                          
+        }
 
                 }
 }
