@@ -1,3 +1,70 @@
+#' Triple factorial scheme plus an additional treatment
+#' in CRD
+#'
+#' \code{fat3.ad.crd} Analyses experiments in balanced
+#' Completely Randomized Design in triple factorial
+#' scheme with an additional treatment, considering a
+#' fixed model.
+#' @param factor1 Numeric or complex vector containing the
+#' factor 1 levels.
+#' @param factor2 Numeric or complex vector containing the
+#' factor 2 levels.
+#' @param factor3 Numeric or complex vector containing the
+#' factor 3 levels.
+#' @param repet Numeric or complex vector containing the
+#' replications.
+#' @param resp Numeric or complex vector containing the
+#' response variable.
+#' @param respAd Numeric or complex vector containing the
+#' additional treatment.
+#' @param quali Logic. If TRUE (default), the treatments
+#' are assumed qualitative, if FALSE, quantitatives.
+#' @param mcomp Allows choosing the multiple comparison
+#' test; the \emph{default} is the test of Tukey, however,
+#' the options are: the LSD test ('lsd'), the LSD test with
+#' Bonferroni protection ('lsdb'), the test of Duncan
+#' ('duncan'), the test of Student-Newman-Keuls ('snk'),
+#' the test of Scott-Knott ('sk'), the Calinski and
+#' Corsten test ('ccF') and bootstrap multiple
+#' comparison's test ('ccboot').
+#' @param fac.names Allows labeling the factors 1, 2 and 3.
+#' @param sigT The signficance to be used for the multiple
+#' comparison test; the default is 5\%.
+#' @param sigF The signficance to be used for the F test of
+#' ANOVA; the default is 5\%.
+#' @details The arguments sigT and mcomp will be used only
+#' when the treatment are qualitative.
+#' @return The output contains the ANOVA of the referred
+#' CRD, the Shapiro-Wilk normality test for the residuals
+#' of the model, the fitted regression models (when the
+#' treatments are quantitative) and/or the multiple
+#' comparison tests (when the treatments are qualitative).
+#' @references HEALY, M. J. R. The analysis of a
+#' factorial experiment with additional treatments.
+#' Journal of Agricultural Science, Cambridge, v. 47,
+#' p. 205-206. 1956.
+#' @author Eric B Ferreira,
+#'  \email{eric.ferreira@@unifal-mg.edu.br}
+#' @author Denismar Alves Nogueira
+#' @author Portya Piscitelli Cavalcanti
+#' @note The \code{\link{graphics}} can be used to
+#' construct regression plots and \code{\link{plotres}}
+#' for residuals plots.
+#' @seealso \code{\link{fat2.crd}},
+#' \code{\link{fat2.rbd}}, \code{\link{fat3.crd}},
+#' \code{\link{fat3.rbd}}, \code{\link{fat2.ad.crd}},
+#' \code{\link{fat2.ad.rbd}}, \code{\link{fat3.ad.crd}}
+#' and \code{\link{fat3.ad.rbd}}.
+#' @examples
+#' data(ex6)
+#' attach(ex6)
+#' data(respAd)
+#' fat3.ad.crd(fatorA, fatorB, fatorC, rep, resp, respAd,
+#' quali = c(TRUE, TRUE, TRUE), mcomp = "duncan",
+#' fac.names = c("Factor A", "Factor B", "Factor C"),
+#' sigT = 0.05, sigF = 0.05)
+#' @export
+
 fat3.ad.crd <-
 function(factor1, factor2, factor3, repet, resp, respAd, quali=c(TRUE,TRUE,TRUE), mcomp='tukey', fac.names=c('F1','F2','F3'), sigT=0.05, sigF=0.05) {
 
@@ -16,7 +83,6 @@ nv3<-length(summary(Fator3))   #Diz quantos niveis tem o fator 3.
 J<-(length(resp))/(nv1*nv2*nv3)
 n.trat2<-nv1*nv2
 n.trat3<-nv1*nv2*nv3
-
 lf1<-levels(Fator1)
 lf2<-levels(Fator2)
 lf3<-levels(Fator3)
@@ -30,7 +96,6 @@ SQab<-anavaF3[[1]][4,2]
 SQac<-anavaF3[[1]][5,2]
 SQbc<-anavaF3[[1]][6,2]
 SQabc<-anavaF3[[1]][7,2]
-
 gla=nv1-1
 glb=nv2-1
 glc=nv3-1
@@ -38,7 +103,6 @@ glab=(nv1-1)*(nv2-1)
 glac=(nv1-1)*(nv3-1)
 glbc=(nv2-1)*(nv3-1)
 glabc=(nv1-1)*(nv2-1)*(nv3-1)
-
 QMa=SQa/gla
 QMb=SQb/glb
 QMc=SQc/glc
@@ -59,19 +123,15 @@ tabF3ad<-data.frame("TRAT"=col1, "REP"=col2, "RESP2"=col3)
 TRAT<-factor(tabF3ad[,1])
 anava<-aov(tabF3ad[,3]~TRAT)
 anavaTr<-summary(anava)
-
 SQad<-anavaTr[[1]][1,2] - (SQa+SQb+SQc+SQab+SQac+SQbc+SQabc)
 SQE<-anavaTr[[1]][2,2]
 SQT<-anavaTr[[1]][1,2]+anavaTr[[1]][2,2]
-
 glad=1
 glT=(nv1*nv2*nv3+1)*J-1
 glE=glT-(gla+glb+glc+glab+glac+glbc+glabc+1)
-
 QMad=SQad/glad
 QME=SQE/glE
 QMT=SQT/glT
-
 Fca=QMa/QME
 Fcb=QMb/QME
 Fcc=QMc/QME
@@ -80,7 +140,6 @@ Fcac=QMac/QME
 Fcbc=QMbc/QME
 Fcabc=QMabc/QME
 Fcad=QMad/QME
-
 pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE))
 
 #Montando a tabela da ANAVA
@@ -98,7 +157,7 @@ print(an)
 cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
 #CV
-cv<-round(sqrt(as.numeric(an[9,3]))/mean(col3)*100, 2)
+cv<-round(sqrt(QME)/mean(col3)*100, 2)
 cat('CV =',cv,'%\n')
 
 #Teste de normalidade
@@ -163,8 +222,8 @@ if(quali[i]==TRUE && pvalor[i]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],an[9,1],an[9,2],sigT)
                     }
-  if(mcomp=='ccf'){
-    ccf(resp,fatores[,i],an[9,1],an[9,2],sigT)
+  if(mcomp=='ccF'){
+    ccF(resp,fatores[,i],an[9,1],an[9,2],sigT)
                     }
                    }
 if(quali[i]==TRUE && pvalor[i]>sigF) {
@@ -272,8 +331,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -361,8 +420,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -386,8 +445,8 @@ ii<-ii+1
 if(pvalor[5]>sigF && pvalor[6]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[3],'
 ------------------------------------------------------------------------\n')
-  
-  i<-3 
+
+  i<-3
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -413,11 +472,11 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -427,13 +486,13 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -443,10 +502,10 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 
 }
@@ -524,8 +583,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
                                           }
                          }
     else{  #regressao
@@ -613,8 +672,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -638,8 +697,8 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[5]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[2],'
 ------------------------------------------------------------------------\n')
-  
-  i<-2 
+
+  i<-2
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -665,11 +724,11 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -679,13 +738,13 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -695,10 +754,10 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 }
 
@@ -775,8 +834,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -864,8 +923,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -889,7 +948,7 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[5]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[1],'
 ------------------------------------------------------------------------\n')
-  
+
   i<-1
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
@@ -916,11 +975,11 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -930,13 +989,13 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -946,10 +1005,10 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 }
 
@@ -989,7 +1048,7 @@ anavad7<-data.frame("DF"=c(glf,glE),
 "Fc"=c(c(round((QM/QME),6)), ' '),
 "Pr>Fc"=c(c(round(1-pf(QM/QME,glf,glE),6)),' '))
 colnames(anavad7)[5]="Pr>Fc"
-rownames(anavad7)=c(rn,"Residuals")       
+rownames(anavad7)=c(rn,"Residuals")
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(anavad7)
@@ -1026,8 +1085,8 @@ ii<-0
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
                                             }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
                                         }
                         }
     else{  #regressao
@@ -1116,8 +1175,8 @@ for(k in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
                                            }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -1166,7 +1225,7 @@ anavad9<-data.frame("DF"=c(glf,glE),
 "Fc"=c(c(round((QM/QME),6)), ' '),
 "Pr>Fc"=c(c(round(1-pf(QM/QME,glf,glE),6)),' '))
 colnames(anavad9)[5]="Pr>Fc"
-rownames(anavad9)=c(rn,"Residuals")       
+rownames(anavad9)=c(rn,"Residuals")
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(anavad9)
@@ -1201,9 +1260,9 @@ for(k in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
                                         }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
-                                            }                
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
+                                            }
                         }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'
