@@ -1,3 +1,68 @@
+#' Triple factorial scheme plus an additional treatment in RBD
+#'
+#' \code{fat3.ad.rbd} Analyses experiments in balanced
+#' Randomized Blocks Designs in triple factorial scheme with
+#' an additional treatment, considering a fixed model.
+#' @param factor1 Numeric or complex vector containing the
+#' factor 1 levels.
+#' @param factor2 Numeric or complex vector containing the
+#' factor 2 levels.
+#' @param factor3 Numeric or complex vector containing the
+#' factor 3 levels.
+#' @param block Numeric or complex vector containing the
+#' blocks.
+#' @param resp Numeric or complex vector containing the
+#' response variable.
+#' @param respAd Numeric or complex vector containing the
+#' additional treatment.
+#' @param quali Logic. If TRUE (default), the treatments
+#' are assumed qualitative, if FALSE, quantitatives.
+#' @param mcomp Allows choosing the multiple comparison
+#' test; the \emph{default} is the test of Tukey, however,
+#' the options are: the LSD test ('lsd'), the LSD test with
+#' Bonferroni protection ('lsdb'), the test of Duncan
+#' ('duncan'), the test of Student-Newman-Keuls ('snk'),
+#' the test of Scott-Knott ('sk'), the Calinski and
+#' Corsten test ('ccF') and bootstrap multiple
+#' comparison's test ('ccboot').
+#' @param fac.names Allows labeling the factors 1, 2 and 3.
+#' @param sigT The signficance to be used for the multiple
+#' comparison test; the default is 5\%.
+#' @param sigF The signficance to be used for the F test of
+#' ANOVA; the default is 5\%.
+#' @details The arguments sigT and mcomp will be used only
+#' when the treatment are qualitative.
+#' @return The output contains the ANOVA of the referred
+#' CRD, the Shapiro-Wilk normality test for the residuals
+#' of the model, the fitted regression models (when the
+#' treatments are quantitative) and/or the multiple
+#' comparison tests (when the treatments are qualitative).
+#' @references HEALY, M. J. R. The analysis of a
+#' factorial experiment with additional treatments.
+#' Journal of Agricultural Science, Cambridge, v. 47,
+#' p. 205-206. 1956.
+#' @author Eric B Ferreira,
+#'  \email{eric.ferreira@@unifal-mg.edu.br}
+#' @author Denismar Alves Nogueira
+#' @author Portya Piscitelli Cavalcanti
+#' @note The \code{\link{graphics}} can be used to
+#' construct regression plots and \code{\link{plotres}}
+#' for residuals plots.
+#' @seealso \code{\link{fat2.crd}},
+#' \code{\link{fat2.rbd}}, \code{\link{fat3.crd}},
+#' \code{\link{fat3.rbd}}, \code{\link{fat2.ad.crd}},
+#' \code{\link{fat2.ad.rbd}}, \code{\link{fat3.ad.crd}}
+#' and \code{\link{fat3.ad.crd}}.
+#' @examples
+#' data(ex6)
+#' attach(ex6)
+#' data(respAd)
+#' fat3.ad.rbd(fatorA, fatorB, fatorC, rep, resp, respAd,
+#' quali = c(TRUE, TRUE, TRUE), mcomp = "snk", fac.names =
+#' c("Factor A", "Factor B", "Factor C"), sigT = 0.05,
+#' sigF = 0.05)
+#' @export
+
 fat3.ad.rbd <-
 function(factor1, factor2, factor3, block, resp, respAd, quali=c(TRUE,TRUE,TRUE), mcomp='tukey', fac.names=c('F1','F2','F3'), sigT=0.05, sigF=0.05) {
 
@@ -17,7 +82,6 @@ nv3<-length(summary(Fator3))   #Diz quantos niveis tem o fator 3.
 J<-(length(resp))/(nv1*nv2*nv3)
 n.trat2<-nv1*nv2
 n.trat3<-nv1*nv2*nv3
-
 lf1<-levels(Fator1)
 lf2<-levels(Fator2)
 lf3<-levels(Fator3)
@@ -31,7 +95,6 @@ SQab<-anavaF3[[1]][5,2]
 SQac<-anavaF3[[1]][6,2]
 SQbc<-anavaF3[[1]][7,2]
 SQabc<-anavaF3[[1]][8,2]
-
 glB=J-1
 gla=nv1-1
 glb=nv2-1
@@ -40,8 +103,6 @@ glab=(nv1-1)*(nv2-1)
 glac=(nv1-1)*(nv3-1)
 glbc=(nv2-1)*(nv3-1)
 glabc=(nv1-1)*(nv2-1)*(nv3-1)
-
-
 QMa=SQa/gla
 QMb=SQb/glb
 QMc=SQc/glc
@@ -49,7 +110,6 @@ QMab=SQab/glab
 QMac=SQac/glac
 QMbc=SQbc/glbc
 QMabc=SQabc/glabc
-
 #Anava de todos os tratamentos do experimento (fatorial 3 + adicional)
 col1<-numeric(0)
 for(i in 1:n.trat3) {
@@ -63,21 +123,17 @@ TRAT<-factor(tabF3ad[,1])
 BLOCK<-factor(tabF3ad[,2])
 anava<-aov(tabF3ad[,3]~ BLOCK + TRAT)
 anavaTr<-summary(anava)
-
 SQB<-anavaTr[[1]][1,2]
 SQad<-anavaTr[[1]][2,2] - (SQa+SQb+SQc+SQab+SQac+SQbc+SQabc)
 SQE<-anavaTr[[1]][3,2]
 SQT<-anavaTr[[1]][1,2]+anavaTr[[1]][2,2]+anavaTr[[1]][3,2]
-
 glad=1
 glT=(nv1*nv2*nv3+1)*J-1
 glE=glT-(glB+gla+glb+glc+glab+glac+glbc+glabc+1)
-
 QMB=SQB/glB
 QMad=SQad/glad
 QME=SQE/glE
 QMT=SQT/glT
-
 FcB=QMB/QME
 Fca=QMa/QME
 Fcb=QMb/QME
@@ -87,7 +143,6 @@ Fcac=QMac/QME
 Fcbc=QMbc/QME
 Fcabc=QMabc/QME
 Fcad=QMad/QME
-
 pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE))
 
 #Montando a tabela da ANAVA
@@ -105,7 +160,7 @@ print(an)
 cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
 #CV
-cv<-round(sqrt(as.numeric(an[10,3]))/mean(col3)*100, 2)
+cv<-round(sqrt(QME)/mean(col3)*100, 2)
 cat('CV =',cv,'%\n')
 
 #Teste de normalidade
@@ -169,8 +224,8 @@ if(quali[i]==TRUE && pvalor[i]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],an[10,1],an[10,2],sigT)
                     }
-  if(mcomp=='ccf'){
-    ccf(resp,fatores[,i],an[10,1],an[10,2],sigT)
+  if(mcomp=='ccF'){
+    ccF(resp,fatores[,i],an[10,1],an[10,2],sigT)
                     }
                    }
 if(quali[i]==TRUE && pvalor[i]>sigF) {
@@ -278,8 +333,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -367,8 +422,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                           }
                       }
     else{  #regressao
@@ -392,8 +447,8 @@ ii<-ii+1
 if(pvalor[5]>sigF && pvalor[6]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[3],'
 ------------------------------------------------------------------------\n')
-  
-  i<-3 
+
+  i<-3
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -419,11 +474,11 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -433,13 +488,13 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -449,10 +504,10 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 }
 
@@ -529,8 +584,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -618,8 +673,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                         }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                         }
                       }
     else{  #regressao
@@ -643,7 +698,7 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[6]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[2],'
 ------------------------------------------------------------------------\n')
-  
+
   i<-2
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
@@ -670,11 +725,11 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -684,13 +739,13 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -700,10 +755,10 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 
 }
@@ -781,8 +836,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -870,8 +925,8 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -895,7 +950,7 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[5]>sigF) {
   cat('\nAnalizing the effect of the factor ',fac.names[1],'
 ------------------------------------------------------------------------\n')
-  
+
   i<-1
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
@@ -922,11 +977,11 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -936,13 +991,13 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
@@ -952,10 +1007,10 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 
 }
@@ -996,7 +1051,7 @@ anavad7<-data.frame("DF"=c(glf,glE),
 "Fc"=c(c(round((QM/QME),6)), ' '),
 "Pr>Fc"=c(c(round(1-pf(QM/QME,glf,glE),6)),' '))
 colnames(anavad7)[5]="Pr>Fc"
-rownames(anavad7)=c(rn,"Residuals")       
+rownames(anavad7)=c(rn,"Residuals")
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(anavad7)
@@ -1033,8 +1088,8 @@ ii<-0
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
                                           }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -1123,8 +1178,8 @@ for(k in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
                                             }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
@@ -1173,7 +1228,7 @@ anavad9<-data.frame("DF"=c(glf,glE),
 "Fc"=c(c(round((QM/QME),6)), ' '),
 "Pr>Fc"=c(c(round(1-pf(QM/QME,glf,glE),6)),' '))
 colnames(anavad9)[5]="Pr>Fc"
-rownames(anavad9)=c(rn,"Residuals")       
+rownames(anavad9)=c(rn,"Residuals")
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(anavad9)
@@ -1208,8 +1263,8 @@ for(k in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=='ccf'){
-                          ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=='ccF'){
+                          ccF(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
                                           }
                         }
     else{  #regressao
