@@ -1,6 +1,59 @@
+#' Split-plots in RBD
+#'
+#' \code{split2.rbd} Analyses experiments in Split-plot scheme
+#' in balanced Randomized Blocks Design, considering a
+#' fixed model.
+#' @param factor1 Numeric or complex vector containing the
+#' factor 1 levels.
+#' @param factor2 Numeric or complex vector containing the
+#' factor 2 levels.
+#' @param block Numeric or complex vector containing the blocks.
+#' @param resp Numeric or complex vector containing the
+#' response variable.
+#' @param quali Logic. If TRUE (default), the treatments
+#' are assumed qualitative, if FALSE, quantitatives.
+#' @param mcomp Allows choosing the multiple comparison
+#' test; the \emph{default} is the test of Tukey, however,
+#' the options are: the LSD test ('lsd'), the LSD test
+#' with Bonferroni protection ('lsdb'), the test of Duncan
+#' ('duncan'), the test of Student-Newman-Keuls ('snk'),
+#' the test of Scott-Knott ('sk'), the Calinski and
+#' Corsten test ('ccF') and bootstrap multiple comparison's
+#' test ('ccboot').
+#' @param fac.names Allows labeling the factors 1 and 2.
+#' @param sigT The signficance to be used for the multiple
+#' comparison test; the default is 5\%.
+#' @param sigF The signficance to be used for the F test
+#' of ANOVA; the default is 5\%.
+#' @details The arguments sigT and mcomp will be used only
+#' when the treatment are qualitative.
+#' @return The output contains the ANOVA of the referred
+#' RBD, the Shapiro-Wilk normality test for the residuals
+#' of the model, the fitted regression models (when the
+#' treatments are quantitative) and/or the multiple
+#' comparison tests (when the treatments are qualitative).
+#' @references BANZATTO, D. A.; KRONKA, S. N.
+#' Experimentacao Agricola. 4 ed. Jaboticabal: Funep.
+#' 2006. 237 p.
+#' @author Eric B Ferreira,
+#'  \email{eric.ferreira@@unifal-mg.edu.br}
+#' @author Denismar Alves Nogueira
+#' @author Portya Piscitelli Cavalcanti
+#' @note The \code{\link{graphics}} can be used to
+#' construct regression plots and \code{\link{plotres}}
+#' for residuals plots.
+#' @seealso \code{\link{split2.crd}} and \code{\link{strip}}.
+#' @examples
+#' data(ex)
+#' attach(ex)
+#' split2.rbd(trat, dose, rep, resp, quali = c(TRUE, FALSE),
+#' mcomp = "tukey", fac.names = c("Treatament", "Dose"),
+#' sigT = 0.05, sigF = 0.05)
+#' @export
+
 split2.rbd <-
 function(factor1, factor2, block, resp, quali=c(TRUE,TRUE), mcomp='tukey', fac.names=c('F1','F2'), sigT=0.05, sigF=0.05) {
-                                                                                                                                               
+
 cat('------------------------------------------------------------------------\nLegend:\n')
 cat('FACTOR 1 (plot): ',fac.names[1],'\n')
 cat('FACTOR 2 (split-plot): ',fac.names[2],'\n------------------------------------------------------------------------\n\n')
@@ -26,7 +79,7 @@ rownames(tab)<-c(fac.names[1],'Block','Error a',fac.names[2],paste(fac.names[1],
 cv1=sqrt(tab[3,3])/mean(resp)*100
 cv2=sqrt(tab[6,3])/mean(resp)*100
 tab<-round(tab,6)
-tab[7,3]<-''
+tab[7,3]<-NA
 
 output<-list('Analysis of Variance Table' = tab)
 cat('------------------------------------------------------------------------\n')
@@ -54,17 +107,17 @@ cat('\nNo significant interaction: analyzing the simple effects
 ------------------------------------------------------------------------\n')
 
 for(i in 1:2){
-    
+
 #Para os fatores QUALITATIVOS, teste de medias
 if(quali[i]==TRUE && as.numeric(tab[cont[i],5])<=sigF) {
     cat(fac.names[i])
-    
+
     if(mcomp=='tukey'){
     tukey(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
                     }
   if(mcomp=='duncan'){
-    duncan(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)            
-                    }                   
+    duncan(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
+                    }
   if(mcomp=='lsd'){
     lsd(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
                     }
@@ -80,8 +133,8 @@ if(quali[i]==TRUE && as.numeric(tab[cont[i],5])<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
                    }
-  if(mcomp=='ccf'){
-    ccf(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
+  if(mcomp=='ccF'){
+    ccF(resp,fatores[,i],as.numeric(tab[3*i,1]), as.numeric(tab[3*i,2]),sigT)
                   }
            }
 
@@ -156,24 +209,24 @@ nome.f1f2<-c(nome.f1f2,'Pooled Error')
 rownames(tab.f1f2)<-nome.f1f2
 tab.f1f2<-round(tab.f1f2,6)
 tab.f1f2[nv2+1,2]<-tab.f1f2[nv2+1,3]*tab.f1f2[nv2+1,1]
-tab.f1f2[nv2+1,5]<-tab.f1f2[nv2+1,4]<-''
+tab.f1f2[nv2+1,5]<-tab.f1f2[nv2+1,4]<-NA
 print(tab.f1f2)
     cat('------------------------------------------------------------------------\n\n')
 
 for(i in 1:nv2) {
 
     cat('\n',fac.names[1], 'inside of', fac.names[2], l2[i] )
-    cat('\n------------------------------------------------------------------------')     
+    cat('\n------------------------------------------------------------------------')
+
+  if(quali[1]==TRUE & as.numeric(tab.f1f2[i,5])<=sigF) {
 
-  if(quali[1]==TRUE & as.numeric(tab.f1f2[i,5])<=sigF) {             
-      
     if(mcomp=='tukey'){
     tukey(resp[fatores[,2]==l2[i]], fatores[,1][fatores[,2]==l2[i]], as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]), sigT)
                       }
 
   if(mcomp=='duncan'){
-    duncan(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)            
-                    }                   
+    duncan(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)
+                    }
 
   if(mcomp=='lsd'){
     lsd(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)
@@ -193,16 +246,16 @@ for(i in 1:nv2) {
   if(mcomp=='ccboot'){
     ccboot(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)
                     }
-  if(mcomp=='ccf'){
-    ccf(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)
+  if(mcomp=='ccF'){
+    ccF(resp[fatores[,2]==l2[i]],fatores[,1][fatores[,2]==l2[i]],as.numeric(tab.f1f2[nv2+1,1]),as.numeric(tab.f1f2[nv2+1,2]),sigT)
                     }
                                                    }
 
-if(quali[1]==FALSE & as.numeric(tab.f1f2[i,5])<sigF) {             
+if(quali[1]==FALSE & as.numeric(tab.f1f2[i,5])<sigF) {
     reg.poly(resp[fatores[,2]==l2[i]], fatores[,1][fatores[,2]==l2[i]], as.numeric(tab.f1f2[nv2+1,1]),
     as.numeric(tab.f1f2[nv2+1,2]), as.numeric(tab.f1f2[i,1]), as.numeric(tab.f1f2[i,2]))
                                                    }
-            
+
 if(as.numeric(tab.f1f2[i,5])>sigF) {
     cat('\nAccording to F test, the means of this factor are not different.\n')
     cat('------------------------------------------------------------------------\n')
@@ -245,7 +298,7 @@ nome.f2f1<-c(nome.f2f1, paste(fac.names[2], ' : ', fac.names[1],' ',l1[j],' ',se
 nome.f2f1<-c(nome.f2f1,'Error b')
 rownames(tab.f2f1)<-nome.f2f1
 tab.f2f1<-round(tab.f2f1,6)
-tab.f2f1[nv1+1,5]<-tab.f2f1[nv1+1,4]<-''
+tab.f2f1[nv1+1,5]<-tab.f2f1[nv1+1,4]<-NA
 print(tab.f2f1)
     cat('------------------------------------------------------------------------\n\n')
 
@@ -253,18 +306,18 @@ print(tab.f2f1)
 for(i in 1:nv1) {
 
     cat('\n',fac.names[2], 'inside of', fac.names[1], l1[i] )
-    cat('\n------------------------------------------------------------------------')     
+    cat('\n------------------------------------------------------------------------')
 
 
-  if(quali[2]==TRUE & as.numeric(tab.f2f1[i,5])<sigF) {             
-    
+  if(quali[2]==TRUE & as.numeric(tab.f2f1[i,5])<sigF) {
+
     if(mcomp=='tukey'){
     tukey(resp[fatores[,1]==l1[i]], fatores[,2][fatores[,1]==l1[i]], as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
                     }
 
   if(mcomp=='duncan'){
     duncan(resp[fatores[,1]==l1[i]],fatores[,2][fatores[,1]==l1[i]],as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
-                    }                   
+                    }
 
   if(mcomp=='lsd'){
     lsd(resp[fatores[,1]==l1[i]],fatores[,2][fatores[,1]==l1[i]],as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
@@ -284,18 +337,18 @@ for(i in 1:nv1) {
   if(mcomp=='ccboot'){
     ccboot(resp[fatores[,1]==l1[i]],fatores[,2][fatores[,1]==l1[i]],as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
                     }
-  if(mcomp=='ccf'){
-    ccf(resp[fatores[,1]==l1[i]],fatores[,2][fatores[,1]==l1[i]],as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
+  if(mcomp=='ccF'){
+    ccF(resp[fatores[,1]==l1[i]],fatores[,2][fatores[,1]==l1[i]],as.numeric(tab.f2f1[nv1+1,1]),as.numeric(tab.f2f1[nv1+1,2]),sigT)
                     }
     cat('------------------------------------------------------------------------\n\n')
                                                       }
-    
+
 
   if(quali[2]==FALSE & as.numeric(tab.f2f1[i,5])<sigF){            #Fazer regressao
-    reg.poly(resp[fatores[,1]==l1[i]], fatores[,2][fatores[,1]==l1[i]], as.numeric(tab.f2f1[nv1+1,1]), 
+    reg.poly(resp[fatores[,1]==l1[i]], fatores[,2][fatores[,1]==l1[i]], as.numeric(tab.f2f1[nv1+1,1]),
     as.numeric(tab.f2f1[nv1+1,2]), as.numeric(tab.f2f1[i,1]), as.numeric(tab.f2f1[i,2]))
                                                    }
-                   
+
 
 if(as.numeric(tab.f2f1[i,5])>sigF) {
     cat('\nAccording to F test, the means of this factor are not different.\n')
@@ -304,7 +357,7 @@ if(as.numeric(tab.f2f1[i,5])>sigF) {
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
     cat('------------------------------------------------------------------------\n')
-                                                }                 
+                                                }
 
 }
 
